#ifndef GFX_FUNCTIONS_H
#define GFX_FUNCTIONS_H
#include <SDL/SDL.h>
#include <SDL/SDL_image.h>

#if SDL_BYTEORDER == SDL_BIG_ENDIAN
        #define RMASK 0xff000000
        #define GMASK 0x00ff0000
        #define BMASK 0x0000ff00
        #define AMASK 0x000000ff
#else
        #define RMASK 0x000000ff
        #define GMASK 0x0000ff00
        #define BMASK 0x00ff0000
        #define AMASK 0xff000000
#endif

#define MAXFREEPOINTERS 50

extern void gfx_putpixel(SDL_Surface *img, int x, int y, Uint8 R, Uint8 G, Uint8 B);
extern void gfx_putrawpixel(SDL_Surface *surface, int x, int y, Uint32 pixel);
extern Uint32 gfx_getrawpixel(SDL_Surface *img, int x, int y);
extern void gfx_getpixel(SDL_Surface *img, int x, int y, Uint8 *R, Uint8 *G, Uint8 *B);
extern void Slock(SDL_Surface *img);
extern void Sulock(SDL_Surface *img);
extern int gfx_init(int xres, int yres, int bdepth, Uint32 flags);
extern void gfx_blit(SDL_Surface *target, int cx, int cy, SDL_Surface *img);
void gfx_blitarea(SDL_Surface *target, int cx, int cy, SDL_Surface *img, int rx1, int ry1, int rx2, int ry2);
extern void gfx_scale_blit(SDL_Surface *target, int blitx, int blity, int xblitsize, int yblitsize, SDL_Surface *img);
extern void gfx_rotblit(SDL_Surface *target, int x, int y, int rotx, int roty, float ang, float scale, SDL_Surface *img);
extern void gfx_calcrotarea(int x, int y, int rotx, int roty, float ang, float scale, SDL_Surface *img, int *minx, int *miny, int *maxx, int *maxy);
void gfx_poly_area(int *points, int numpoints, int *x1, int *y1, int *x2, int *y2);
extern SDL_Surface *gfx_getimage(SDL_Surface *src, int x1, int y1, int x2, int y2);
extern void gfx_line(SDL_Surface *img, int x1, int y1, int x2, int y2, Uint8 R, Uint8 G, Uint8 B);
extern void gfx_hline(SDL_Surface *img, int x1, int x2, int y, Uint8 R, Uint8 G, Uint8 B, Uint8 A);
extern void gfx_solid_box(SDL_Surface *img, int x1, int y1, int x2, int y2, Uint8 R, Uint8 G, Uint8 B, Uint8 A);
extern void gfx_polygon(SDL_Surface *img, int *pointx, int *pointy, int numpoints, Uint8 R, Uint8 G, Uint8 B, Uint8 A);
extern void gfx_draw_button_base(SDL_Surface *img, int x1, int y1, int x2, int y2, int trimsize, int status, Uint8 R, Uint8 G, Uint8 B);
extern int sgn(int v);
extern SDL_Surface *gfx_load_png(char *filename);
extern void gfx_draw_texture(SDL_Surface *target, int *destpoint, int *sourcepoint, int numpoints, SDL_Surface *source);
extern void gfx_draw_3Dtexture(SDL_Surface *target, int *destpoint, int *sourcepoint, int numpoints, SDL_Surface *source, int *depth);
extern void gfx_copy_dline_to_hline(SDL_Surface *target, int drawx1, int drawx2, int drawy, SDL_Surface *source, int sx1, int sy1, int sx2, int sy2);
extern void gfx_copy_XYline_to_XZline(SDL_Surface *target, int drawx1, int drawz1, int drawx2, int drawz2, int drawy, SDL_Surface *source, int sx1, int sy1, int sx2, int sy2, int *depth);
extern void *gfx_allocate_memory(size_t size);
extern void gfx_free_memory(void);
extern int gfx_add_freepointer(void *ptr);
extern void gfx_free_memory(void);

/***** global variables *****/
extern int x_resolution, y_resolution, screen_depth;
extern SDL_Surface *screen_image;
extern void *free_pointer[MAXFREEPOINTERS];
extern int numfreepointers;

#endif /* ifndef GFX_FUNCTIONS_H */
